==> ejc-probuilddiary-impl-3.0.0-20230712.010030-123-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonQualityEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-工程质量检查、验收情况（质检员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_quality")
public class PersonQualityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="quality_id")
    private Long qualityId; // 工作类别id
    @TableField(value="quality_name")
    private String qualityName; // 工作类别名称
    @TableField(value="quality_code")
    private String qualityCode; // 工作类别编码
    @TableField(value="quality_memo")
    private String qualityMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getQualityId() {
        return qualityId;
    }

    public void setQualityId(Long qualityId) {
        this.qualityId = qualityId;
    }
    public String getQualityName() {
        return qualityName;
    }

    public void setQualityName(String qualityName) {
        this.qualityName = qualityName;
    }
    public String getQualityCode() {
        return qualityCode;
    }

    public void setQualityCode(String qualityCode) {
        this.qualityCode = qualityCode;
    }
    public String getQualityMemo() {
        return qualityMemo;
    }

    public void setQualityMemo(String qualityMemo) {
        this.qualityMemo = qualityMemo;
    }
    
}

==> ejc-probuilddiary-impl-3.0.0-20250403.010345-151-sources.jar: com/ejianc/business/probuilddiary/person/bean/PersonQualityEntity.java <==
package com.ejianc.business.probuilddiary.person.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 个人日志-工程质量检查、验收情况（质检员）
 * 
 * @author generator
 * 
 */
 @TableName("ejc_probuilddiary_person_quality")
public class PersonQualityEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="person_id")
    private Long personId; // 个人日志id
    @TableField(value="quality_id")
    private Long qualityId; // 工作类别id
    @TableField(value="quality_name")
    private String qualityName; // 工作类别名称
    @TableField(value="quality_code")
    private String qualityCode; // 工作类别编码
    @TableField(value="quality_memo")
    private String qualityMemo; // 工作描述
    @TableField(value = "file_type")
    private String fileType; // 文件类型
    @TableField(value = "log_number")
    private String logNumber;//日志 数目
    @TableField(value="project_id")
    private Long projectId; // 项目id
    @TableField(value="project_name")
    private String projectName; // 项目名称

    public String getLogNumber() {
        return logNumber;
    }

    public void setLogNumber(String logNumber) {
        this.logNumber = logNumber;
    }

    public String getFileType() {
        return fileType;
    }

    public void setFileType(String fileType) {
        this.fileType = fileType;
    }
    
    

    public Long getPersonId() {
        return personId;
    }

    public void setPersonId(Long personId) {
        this.personId = personId;
    }
    public Long getQualityId() {
        return qualityId;
    }

    public void setQualityId(Long qualityId) {
        this.qualityId = qualityId;
    }
    public String getQualityName() {
        return qualityName;
    }

    public void setQualityName(String qualityName) {
        this.qualityName = qualityName;
    }
    public String getQualityCode() {
        return qualityCode;
    }

    public void setQualityCode(String qualityCode) {
        this.qualityCode = qualityCode;
    }
    public String getQualityMemo() {
        return qualityMemo;
    }

    public void setQualityMemo(String qualityMemo) {
        this.qualityMemo = qualityMemo;
    }

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }
}
